==> klaytn_etl_cli-0.2.2-py3-none-any.whl: klaytnetl/jobs/export_contracts_job.py <==
# MIT License
#
# Modifications Copyright (c) klaytn authors
# Copyright (c) 2018 Evgeny Medvedev, evge.medvedev@gmail.com
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.


import json

from klaytnetl.executors.batch_work_executor import BatchWorkExecutor
from blockchainetl.jobs.base_job import BaseJob
from klaytnetl.json_rpc_requests import generate_get_code_json_rpc
from klaytnetl.mappers.contract_mapper import KlaytnContractMapper

from klaytnetl.service.klaytn_contract_service import KlaytnContractService
from klaytnetl.utils import rpc_response_to_result


# Exports contracts bytecode
class ExportContractsJob(BaseJob):
    def __init__(
        self,
        contracts_iterable,
        batch_size,
        batch_web3_provider,
        max_workers,
        item_exporter,
    ):
        self.batch_web3_provider = batch_web3_provider
        self.contracts_iterable = contracts_iterable

        self.batch_work_executor = BatchWorkExecutor(batch_size, max_workers)
        self.item_exporter = item_exporter

        self.contract_service = KlaytnContractService()
        self.contract_mapper = KlaytnContractMapper()

    def _start(self):
        self.item_exporter.open()

    def _export(self):
        self.batch_work_executor.execute(
            self.contracts_iterable, self._export_contracts
        )

    def _export_contracts(self, items):
        block_numbers = {}
        contract_addresses = []
        for item in items:
            block_numbers[item["contract_address"]] = item["block_number"]
            contract_addresses.append(item["contract_address"])

        contracts_code_rpc = list(generate_get_code_json_rpc(contract_addresses))
        response_batch = self.batch_web3_provider.make_batch_request(
            json.dumps(contracts_code_rpc)
        )

        contracts = []
        for response in response_batch:
            # request id is the index of the contract address in contract_addresses list
            request_id = response["id"]
            result = rpc_response_to_result(response)

            contract_address = contract_addresses[request_id]
            block_number = block_numbers[contract_address]

            contract = self._get_contract(contract_address, result, block_number)
            contracts.append(contract)

        for contract in contracts:
            self.item_exporter.export_item(
                self.contract_mapper.contract_to_dict(contract)
            )

    def _get_contract(self, contract_address, rpc_result, block_number):
        contract = self.contract_mapper.rpc_result_to_contract(
            contract_address, rpc_result
        )
        bytecode = contract.bytecode
        function_sighashes = self.contract_service.get_function_sighashes(bytecode)

        contract.block_number = block_number
        contract.function_sighashes = function_sighashes
        contract.is_erc20 = self.contract_service.is_erc20_contract(function_sighashes)
        contract.is_erc721 = self.contract_service.is_erc721_contract(
            function_sighashes
        )
        contract.is_erc1155 = self.contract_service.is_erc1155_contract(
            function_sighashes
        )

        return contract

    def _end(self):
        self.batch_work_executor.shutdown()
        self.item_exporter.close()

==> klaytn_etl_cli-0.3.6-py3-none-any.whl: klaytnetl/jobs/export_contracts_job.py <==
# MIT License
#
# Modifications Copyright (c) klaytn authors
# Copyright (c) 2018 Evgeny Medvedev, evge.medvedev@gmail.com
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.


import json

from klaytnetl.executors.batch_work_executor import BatchWorkExecutor
from blockchainetl.jobs.base_job import BaseJob
from klaytnetl.json_rpc_requests import generate_get_code_json_rpc
from klaytnetl.mappers.contract_mapper import KlaytnContractMapper

from klaytnetl.service.klaytn_contract_service import KlaytnContractService
from klaytnetl.utils import rpc_response_to_result


# Exports contracts bytecode
class ExportContractsJob(BaseJob):
    def __init__(
        self,
        contracts_iterable,
        batch_size,
        batch_web3_provider,
        web3,
        max_workers,
        item_exporter,
    ):
        self.batch_web3_provider = batch_web3_provider
        self.contracts_iterable = contracts_iterable

        self.batch_work_executor = BatchWorkExecutor(batch_size, max_workers)
        self.item_exporter = item_exporter

        self.contract_service = KlaytnContractService(web3)
        self.contract_mapper = KlaytnContractMapper()

    def _start(self):
        self.item_exporter.open()

    def _export(self):
        self.batch_work_executor.execute(
            self.contracts_iterable, self._export_contracts
        )

    def _export_contracts(self, items):
        block_numbers = {}
        contract_addresses = []
        for item in items:
            block_numbers[item["contract_address"]] = item["block_number"]
            contract_addresses.append(item["contract_address"])

        contracts_code_rpc = list(generate_get_code_json_rpc(contract_addresses))
        response_batch = self.batch_web3_provider.make_batch_request(
            json.dumps(contracts_code_rpc)
        )

        contracts = []
        for response in response_batch:
            # request id is the index of the contract address in contract_addresses list
            request_id = response["id"]
            result = rpc_response_to_result(response)

            contract_address = contract_addresses[request_id]
            block_number = block_numbers[contract_address]

            contract = self._get_contract(contract_address, result, block_number)
            contracts.append(contract)

        for contract in contracts:
            self.item_exporter.export_item(
                self.contract_mapper.contract_to_dict(contract)
            )

    def _get_contract(self, contract_address, rpc_result, block_number):
        contract = self.contract_mapper.rpc_result_to_contract(
            contract_address, rpc_result
        )
        bytecode = contract.bytecode
        function_sighashes = self.contract_service.get_function_sighashes(bytecode)

        contract.block_number = block_number
        contract.function_sighashes = function_sighashes
        contract.is_erc20 = self.contract_service.is_erc20_contract(
            contract_address, function_sighashes, block_number
        )
        contract.is_erc721 = self.contract_service.is_erc721_contract(
            contract_address, function_sighashes, block_number
        )
        contract.is_erc1155 = self.contract_service.is_erc1155_contract(
            contract_address, function_sighashes, block_number
        )

        return contract

    def _end(self):
        self.batch_work_executor.shutdown()
        self.item_exporter.close()
